# Generated by Django 4.2.6 on 2024-06-04 11:50

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import mad_notifications.utils
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("auth", "0012_alter_user_first_name_max_length"),
    ]

    operations = [
        migrations.CreateModel(
            name="NotificationTemplate",
            fields=[
                (
                    "id",
                    models.BigAutoField(primary_key=True, serialize=False, unique=True),
                ),
                ("name", models.CharField(help_text="Template Name", max_length=225)),
                (
                    "slug",
                    models.SlugField(
                        help_text="Unique Template identifier",
                        max_length=225,
                        unique=True,
                    ),
                ),
                (
                    "subject",
                    models.CharField(
                        default="Email Subject here",
                        help_text="Email Subject",
                        max_length=225,
                    ),
                ),
                (
                    "content",
                    models.TextField(
                        blank=True,
                        help_text='Templated content of the email. <a href="https://docs.djangoproject.com/en/dev/topics/templates/" target="_target">Refer to docs for more details</a>. Supports HTML',
                        null=True,
                    ),
                ),
                (
                    "mobile_content",
                    models.TextField(
                        blank=True,
                        help_text='Templated content for SMS, and Push notification etc. <a href="https://docs.djangoproject.com/en/dev/topics/templates/" target="_target">Refer to docs for more details</a>. Supports HTML',
                        null=True,
                    ),
                ),
                (
                    "from_email",
                    models.CharField(
                        blank=True,
                        help_text="For example: No Reply &lt;noreply@example.com&gt;",
                        max_length=225,
                        null=True,
                    ),
                ),
                (
                    "from_phone",
                    phonenumber_field.modelfields.PhoneNumberField(
                        blank=True,
                        help_text="Phone number to send this message from.",
                        max_length=128,
                        null=True,
                        region=None,
                    ),
                ),
                ("admin_note", models.TextField(blank=True, null=True)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "ordering": ["-id"],
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="UserNotificationConfig",
            fields=[
                (
                    "user",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        primary_key=True,
                        serialize=False,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                ("allow_email", models.BooleanField(default=True)),
                ("allow_push", models.BooleanField(default=True)),
                ("allow_sms", models.BooleanField(default=True)),
                ("allow_whatsapp", models.BooleanField(default=True)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Notification",
            fields=[
                (
                    "id",
                    models.BigAutoField(primary_key=True, serialize=False, unique=True),
                ),
                ("title", models.CharField(max_length=254)),
                (
                    "content",
                    models.TextField(
                        help_text="Notification content for web/email", null=True
                    ),
                ),
                (
                    "mobile_content",
                    models.TextField(
                        help_text="Notification content for web/email sms, push, etc.",
                        null=True,
                    ),
                ),
                (
                    "image",
                    models.FileField(
                        blank=True,
                        null=True,
                        upload_to=mad_notifications.utils.notification_unique_file_path,
                    ),
                ),
                (
                    "icon",
                    models.FileField(
                        blank=True,
                        null=True,
                        upload_to=mad_notifications.utils.notification_unique_file_path,
                    ),
                ),
                ("is_read", models.BooleanField(default=False)),
                ("actions", models.JSONField(blank=True, default=dict)),
                (
                    "data",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        help_text="All keys and values in the dictionary must be strings.",
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "template",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="mad_notifications.notificationtemplate",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "ordering": ["-id"],
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Device",
            fields=[
                (
                    "id",
                    models.BigAutoField(primary_key=True, serialize=False, unique=True),
                ),
                ("token", models.TextField(blank=True, null=True)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                (
                    "user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "ordering": ["-id"],
                "abstract": False,
            },
        ),
    ]
